@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import re
+from ckeditor.widgets import CKEditorWidget
 
 from django import forms
 from django.utils.translation import ugettext_lazy
@@ -16,7 +17,6 @@ class ItemForm(CleanHtmlFormMixin, CssClassMixin, forms.ModelForm):
     """
     Form to create of update an item.
     """
-
     clean_html_fields = ('text', )
 
     parent = TreeNodeChoiceField(
@@ -32,7 +32,8 @@ class ItemForm(CleanHtmlFormMixin, CssClassMixin, forms.ModelForm):
 
     class Meta:
         model = Item
-        exclude = ('closed', 'weight', 'content_type', 'object_id')
+        fields = ('item_number', 'title', 'text', 'comment', 'tags', 'type', 'duration', 'parent', 'speaker_list_closed')
+        widgets = {'text': CKEditorWidget(config_name='images')}
 
 
 class RelatedItemForm(ItemForm):
@@ -41,7 +42,7 @@ class RelatedItemForm(ItemForm):
     """
     class Meta:
         model = Item
-        exclude = ('closed', 'type', 'weight', 'content_type', 'object_id', 'title', 'text')
+        fields = ('comment', 'duration', 'parent', 'speaker_list_closed')
 
 
 class ItemOrderForm(CssClassMixin, forms.Form):
