@@ -1,44 +1,63 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-    openslides.assignment.models
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    Models for the assignment app.
-
-    :copyright: 2011–2013 by OpenSlides team, see AUTHORS.
-    :license: GNU GPL, see LICENSE for more details.
-"""
 
+from django.contrib.contenttypes.models import ContentType
 from django.core.urlresolvers import reverse
 from django.db import models
-from django.utils.translation import ugettext as _, ugettext_lazy, ugettext_noop
 from django.utils.datastructures import SortedDict
+from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy, ugettext_noop
 
-from openslides.utils.person import PersonField
+from openslides.agenda.models import Item, Speaker
+from openslides.core.models import Tag
 from openslides.config.api import config
-from openslides.projector.api import register_slidemodel
-from openslides.projector.projector import SlideMixin
-from openslides.poll.models import (
-    BasePoll, CountInvalid, CountVotesCast, BaseOption, PublishPollMixin, BaseVote)
-from openslides.agenda.models import Item
+from openslides.poll.models import (BaseOption, BasePoll, BaseVote,
+                                    CollectDefaultVotesMixin,
+                                    PublishPollMixin)
+from openslides.projector.api import get_active_object, update_projector
+from openslides.projector.models import RelatedModelMixin, SlideMixin
+from openslides.utils.exceptions import OpenSlidesError
+from openslides.utils.models import AbsoluteUrlMixin
+from openslides.utils.person import PersonField
+from openslides.utils.utils import html_strong
 
 
-class AssignmentCandidate(models.Model):
+class AssignmentCandidate(RelatedModelMixin, models.Model):
+    """
+    Many2Many table between an assignment and the candidates.
+    """
     assignment = models.ForeignKey("Assignment")
     person = PersonField(db_index=True)
     elected = models.BooleanField(default=False)
     blocked = models.BooleanField(default=False)
 
-    def __unicode__(self):
-        return unicode(self.person)
-
     class Meta:
         unique_together = ("assignment", "person")
 
+    # Will be removed in 2.0 (required for haystack fix)
+    def save(self, *args, **kwargs):
+        super(AssignmentCandidate, self).save(*args, **kwargs)
+        models.signals.m2m_changed.send(sender=self, action='post_add',
+                                        instance=self.assignment)
+
+    # Will be removed in 2.0 (required for haystack fix)
+    def delete(self, *args, **kwargs):
+        super(AssignmentCandidate, self).delete(*args, **kwargs)
+        models.signals.m2m_changed.send(sender=self, action='post_remove',
+                                        instance=self.assignment)
+
+    def __unicode__(self):
+        return unicode(self.person)
+
+    def get_related_model(self):
+        """
+        Returns the assignment
+        """
+        return self.assignment
+
+
+class Assignment(SlideMixin, AbsoluteUrlMixin, models.Model):
+    slide_callback_name = 'assignment'
 
-class Assignment(models.Model, SlideMixin):
-    prefix = ugettext_noop('assignment')
     STATUS = (
         ('sea', ugettext_lazy('Searching for candidates')),
         ('vot', ugettext_lazy('Voting')),
@@ -48,22 +67,49 @@ class Assignment(models.Model, SlideMixin):
     name = models.CharField(max_length=100, verbose_name=ugettext_lazy("Name"))
     description = models.TextField(null=True, blank=True, verbose_name=ugettext_lazy("Description"))
     posts = models.PositiveSmallIntegerField(verbose_name=ugettext_lazy("Number of available posts"))
-    polldescription = models.CharField(
-        max_length=100, null=True, blank=True,
-        verbose_name=ugettext_lazy("Comment on the ballot paper"))
+    poll_description_default = models.CharField(
+        max_length=79, null=True, blank=True,
+        verbose_name=ugettext_lazy("Default comment on the ballot paper"))
     status = models.CharField(max_length=3, choices=STATUS, default='sea')
+    tags = models.ManyToManyField(Tag, blank=True)
+
+    class Meta:
+        permissions = (
+            ('can_see_assignment', ugettext_noop('Can see elections')),  # TODO: Add plural s to the codestring
+            ('can_nominate_other', ugettext_noop('Can nominate another person')),
+            ('can_nominate_self', ugettext_noop('Can nominate oneself')),
+            ('can_manage_assignment', ugettext_noop('Can manage elections')),  # TODO: Add plural s also to the codestring
+        )
+        ordering = ('name',)
+        verbose_name = ugettext_noop('Election')
+
+    def __unicode__(self):
+        return self.name
+
+    def get_absolute_url(self, link='detail'):
+        if link == 'detail':
+            url = reverse('assignment_detail', args=[str(self.pk)])
+        elif link == 'update':
+            url = reverse('assignment_update', args=[str(self.pk)])
+        elif link == 'delete':
+            url = reverse('assignment_delete', args=[str(self.pk)])
+        else:
+            url = super(Assignment, self).get_absolute_url(link)
+        return url
+
+    def get_slide_context(self, **context):
+        context.update({
+            'polls': self.poll_set.filter(published=True),
+            'vote_results': self.vote_results(only_published=True)})
+        return super(Assignment, self).get_slide_context(**context)
 
     def set_status(self, status):
-        error = True
-        for a, b in Assignment.STATUS:
-            if status == a:
-                error = False
-                break
-        if error:
-            raise NameError(_('%s is not a valid status.') % status)
+        status_dict = dict(self.STATUS)
+        if status not in status_dict:
+            raise ValueError(_('%s is not a valid status.') % html_strong(status))
         if self.status == status:
-            raise NameError(
-                _('The assignment status is already %s.') % self.status)
+            raise ValueError(
+                _('The election status is already %s.') % html_strong(status_dict[status]))
         self.status = status
         self.save()
 
@@ -153,20 +199,57 @@ class Assignment(models.Model, SlideMixin):
             participants.append(candidate.person)
         participants.sort(key=lambda person: person.sort_name)
         return participants
-        #return candidates.values_list('person', flat=True)
+        # return candidates.values_list('person', flat=True)
 
     def set_elected(self, person, value=True):
         candidate = self.assignment_candidates.get(person=person)
         candidate.elected = value
         candidate.save()
+        # update projector if assignment or assignmentpoll slide is active
+        active_object = get_active_object()
+        if (type(active_object) is type(self) and active_object.pk == self.pk) or \
+           (type(active_object) is AssignmentPoll and active_object.assignment_id == self.pk):
+            update_projector()
 
     def is_elected(self, person):
         return person in self.elected
 
     def gen_poll(self):
-        poll = AssignmentPoll(assignment=self)
-        poll.save()
+        """
+        Creates an new poll for the assignment and adds all candidates to all
+        lists of speakers of related agenda items.
+        """
+        if config['assignment_poll_vote_values'] == 'votes':
+            yesnoabstain = False
+        elif config['assignment_poll_vote_values'] == 'yesnoabstain':
+            yesnoabstain = True
+        else:
+            # config['assignment_poll_vote_values'] == 'auto'
+            # candidates <= available posts -> yes/no/abstain
+            if len(self.candidates) <= (self.posts - len(self.elected)):
+                yesnoabstain = True
+            else:
+                yesnoabstain = False
+
+        poll = AssignmentPoll.objects.create(
+            assignment=self,
+            description=self.poll_description_default,
+            yesnoabstain=yesnoabstain)
         poll.set_options([{'candidate': person} for person in self.candidates])
+
+        items = Item.objects.filter(content_type=ContentType.objects.get_for_model(Assignment), object_id=self.pk)
+        for item in items:
+            someone_added = None
+            for candidate in self.candidates:
+                try:
+                    someone_added = Speaker.objects.add(candidate, item)
+                except OpenSlidesError:
+                    # The Speaker is already on the list. Do nothing.
+                    # TODO: Find a smart way not to catch the error concerning AnonymousUser.
+                    pass
+            if someone_added is not None:
+                someone_added.check_and_update_projector()
+
         return poll
 
     def vote_results(self, only_published):
@@ -207,49 +290,8 @@ class Assignment(models.Model, SlideMixin):
     def get_agenda_title(self):
         return self.name
 
-    def delete(self):
-        # Remove any Agenda-Item, which is related to this assignment.
-        for item in Item.objects.filter(related_sid=self.sid):
-            item.delete()
-        super(Assignment, self).delete()
-
-    def slide(self):
-        """
-        return the slide dict
-        """
-        polls = self.poll_set
-        data = super(Assignment, self).slide()
-        data['assignment'] = self
-        data['title'] = self.name
-        data['some_polls_available'] = polls.exists()
-        data['polls'] = polls.filter(published=True)
-        data['vote_results'] = self.vote_results(only_published=True)
-        data['assignment_publish_winner_results_only'] = \
-            config['assignment_publish_winner_results_only']
-        data['template'] = 'projector/Assignment.html'
-        return data
-
-    def get_absolute_url(self, link='detail'):
-        if link == 'detail' or link == 'view':
-            return reverse('assignment_view', args=[str(self.id)])
-        if link == 'update' or link == 'edit':
-            return reverse('assignment_edit', args=[str(self.id)])
-        if link == 'delete':
-            return reverse('assignment_delete', args=[str(self.id)])
-
-    def __unicode__(self):
-        return self.name
-
-    class Meta:
-        permissions = (
-            ('can_see_assignment', ugettext_noop('Can see assignments')),  # TODO: Add plural s to the codestring
-            ('can_nominate_other', ugettext_noop('Can nominate another person')),
-            ('can_nominate_self', ugettext_noop('Can nominate oneself')),
-            ('can_manage_assignment', ugettext_noop('Can manage assignments')),  # TODO: Add plural s also to the codestring
-        )
-        ordering = ('name',)
-
-register_slidemodel(Assignment)
+    def get_agenda_title_supplement(self):
+        return '(%s)' % _('Assignment')
 
 
 class AssignmentVote(BaseVote):
@@ -265,46 +307,57 @@ class AssignmentOption(BaseOption):
         return unicode(self.candidate)
 
 
-class AssignmentPoll(BasePoll, CountInvalid, CountVotesCast, PublishPollMixin):
-    option_class = AssignmentOption
+class AssignmentPoll(SlideMixin, RelatedModelMixin, CollectDefaultVotesMixin,
+                     PublishPollMixin, AbsoluteUrlMixin, BasePoll):
 
+    slide_callback_name = 'assignmentpoll'
+    """Name of the callback for the slide system."""
+
+    option_class = AssignmentOption
     assignment = models.ForeignKey(Assignment, related_name='poll_set')
-    yesnoabstain = models.NullBooleanField()
+    yesnoabstain = models.BooleanField()
+    description = models.CharField(
+        max_length=79, null=True, blank=True,
+        verbose_name=ugettext_lazy("Comment on the ballot paper"))
+
+    def __unicode__(self):
+        return _("Ballot %d") % self.get_ballot()
+
+    def get_absolute_url(self, link='update'):
+        """
+        Return an URL for the poll.
+
+        The keyargument 'link' can be 'update' or 'delete'.
+        """
+        if link == 'update':
+            url = reverse('assignmentpoll_update', args=[str(self.pk)])
+        elif link == 'delete':
+            url = reverse('assignmentpoll_delete', args=[str(self.pk)])
+        else:
+            url = super(AssignmentPoll, self).get_absolute_url(link)
+        return url
 
     def get_assignment(self):
         return self.assignment
 
+    def get_related_model(self):
+        return self.assignment
+
     def get_vote_values(self):
-        if self.yesnoabstain is None:
-            if config['assignment_poll_vote_values'] == 'votes':
-                self.yesnoabstain = False
-            elif config['assignment_poll_vote_values'] == 'yesnoabstain':
-                self.yesnoabstain = True
-            else:
-                # candidates <= available posts -> yes/no/abstain
-                if len(self.assignment.candidates) <= (self.assignment.posts - len(self.assignment.elected)):
-                    self.yesnoabstain = True
-                else:
-                    self.yesnoabstain = False
-            self.save()
         if self.yesnoabstain:
             return [ugettext_noop('Yes'), ugettext_noop('No'), ugettext_noop('Abstain')]
         else:
             return [ugettext_noop('Votes')]
 
-    def append_pollform_fields(self, fields):
-        CountInvalid.append_pollform_fields(self, fields)
-        CountVotesCast.append_pollform_fields(self, fields)
-
     def get_ballot(self):
         return self.assignment.poll_set.filter(id__lte=self.id).count()
 
-    @models.permalink
-    def get_absolute_url(self, link='view'):
-        if link == 'view':
-            return ('assignment_poll_view', [str(self.id)])
-        if link == 'delete':
-            return ('assignment_poll_delete', [str(self.id)])
+    def get_percent_base_choice(self):
+        return config['assignment_poll_100_percent_base']
 
-    def __unicode__(self):
-        return _("Ballot %d") % self.get_ballot()
+    def append_pollform_fields(self, fields):
+        fields.append('description')
+        super(AssignmentPoll, self).append_pollform_fields(fields)
+
+    def get_slide_context(self, **context):
+        return super(AssignmentPoll, self).get_slide_context(poll=self)
