@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+from cgi import escape
+
 from django.contrib import messages
 from django.core.urlresolvers import reverse
 from django.shortcuts import redirect
@@ -43,31 +45,30 @@ class AssignmentDetail(DetailView):
             context['form'] = self.form_class(self.request.POST)
         else:
             context['form'] = self.form_class()
-        polls = self.object.poll_set.all()
+        polls = self.get_object().poll_set.all()
         if not self.request.user.has_perm('assignment.can_manage_assignment'):
-            polls = self.object.poll_set.filter(published=True)
-            vote_results = self.object.vote_results(only_published=True)
+            polls = self.get_object().poll_set.filter(published=True)
+            vote_results = self.get_object().vote_results(only_published=True)
         else:
-            polls = self.object.poll_set.all()
-            vote_results = self.object.vote_results(only_published=False)
+            polls = self.get_object().poll_set.all()
+            vote_results = self.get_object().vote_results(only_published=False)
 
         blocked_candidates = [
             candidate.person for candidate in
-            self.object.assignment_candidates.filter(blocked=True)]
+            self.get_object().assignment_candidates.filter(blocked=True)]
         context['polls'] = polls
         context['vote_results'] = vote_results
         context['blocked_candidates'] = blocked_candidates
-        context['user_is_candidate'] = self.object.is_candidate(self.request.user)
+        context['user_is_candidate'] = self.get_object().is_candidate(self.request.user)
         return context
 
     def post(self, *args, **kwargs):
-        self.object = self.get_object()
         if self.request.user.has_perm('assignment.can_nominate_other'):
             form = self.form_class(self.request.POST)
             if form.is_valid():
                 user = form.cleaned_data['candidate']
                 try:
-                    self.object.run(user, self.request.user)
+                    self.get_object().run(user, self.request.user)
                 except NameError, e:
                     messages.error(self.request, e)
                 else:
@@ -101,18 +102,17 @@ class AssignmentSetStatusView(SingleObjectMixin, RedirectView):
     url_name = 'assignment_detail'
 
     def pre_redirect(self, *args, **kwargs):
-        self.object = self.get_object()
         status = kwargs.get('status')
         if status is not None:
             try:
-                self.object.set_status(status)
+                self.get_object().set_status(status)
             except ValueError, e:
                 messages.error(self.request, e)
             else:
                 messages.success(
                     self.request,
                     _('Election status was set to: %s.') %
-                    html_strong(self.object.get_status_display())
+                    html_strong(self.get_object().get_status_display())
                 )
 
 
@@ -137,11 +137,10 @@ class AssignmentRunDeleteView(SingleObjectMixin, RedirectView):
     url_name = 'assignment_detail'
 
     def pre_redirect(self, *args, **kwargs):
-        self.object = self.get_object()
-        if self.object.status == 'sea' or self.request.user.has_perm(
+        if self.get_object().status == 'sea' or self.request.user.has_perm(
                 "assignment.can_manage_assignment"):
             try:
-                self.object.delrun(self.request.user, blocked=True)
+                self.get_object().delrun(self.request.user, blocked=True)
             except Exception, e:
                 messages.error(self.request, e)
             else:
@@ -167,7 +166,7 @@ class AssignmentRunOtherDeleteView(SingleObjectMixin, QuestionView):
     def on_clicked_yes(self):
         self._get_person_information()
         try:
-            self.object.delrun(self.person, blocked=False)
+            self.get_object().delrun(self.person, blocked=False)
         except Exception, e:
             self.error = e
         else:
@@ -186,9 +185,8 @@ class AssignmentRunOtherDeleteView(SingleObjectMixin, QuestionView):
         return message
 
     def _get_person_information(self):
-        self.object = self.get_object()
         self.person = get_person(self.kwargs.get('user_id'))
-        self.is_blocked = self.object.is_blocked(self.person)
+        self.is_blocked = self.get_object().is_blocked(self.person)
 
 
 class PollCreateView(SingleObjectMixin, RedirectView):
@@ -197,12 +195,12 @@ class PollCreateView(SingleObjectMixin, RedirectView):
     url_name = 'assignment_detail'
 
     def pre_redirect(self, *args, **kwargs):
-        self.object = self.get_object()
-        self.object.gen_poll()
+        self.get_object().gen_poll()
         messages.success(self.request, _("New ballot was successfully created."))
 
 
 class PollUpdateView(PollFormView):
+    required_permission = 'assignment.can_manage_assignment'
     poll_class = AssignmentPoll
     template_name = 'assignment/assignmentpoll_form.html'
 
@@ -233,15 +231,15 @@ class SetPublishStatusView(SingleObjectMixin, RedirectView):
 
     def pre_redirect(self, *args, **kwargs):
         try:
-            self.object = self.get_object()
+            poll = self.get_object()
         except self.model.DoesNotExist:
             messages.error(self.request, _('Ballot ID %d does not exist.') %
                            int(kwargs['poll_id']))
         else:
-            if self.object.published:
-                self.object.set_published(False)
+            if poll.published:
+                poll.set_published(False)
             else:
-                self.object.set_published(True)
+                poll.set_published(True)
 
 
 class SetElectedView(SingleObjectMixin, RedirectView):
@@ -251,19 +249,18 @@ class SetElectedView(SingleObjectMixin, RedirectView):
     allow_ajax = True
 
     def pre_redirect(self, *args, **kwargs):
-        self.object = self.get_object()
         self.person = get_person(kwargs['user_id'])
         self.elected = kwargs['elected']
-        self.object.set_elected(self.person, self.elected)
+        self.get_object().set_elected(self.person, self.elected)
 
     def get_ajax_context(self, **kwargs):
         if self.elected:
             link = reverse('assignment_user_not_elected',
-                           args=[self.object.id, self.person.person_id])
+                           args=[self.get_object().id, self.person.person_id])
             text = _('not elected')
         else:
             link = reverse('assignment_user_elected',
-                           args=[self.object.id, self.person.person_id])
+                           args=[self.get_object().id, self.person.person_id])
             text = _('elected')
         return {'elected': self.elected, 'link': link, 'text': text}
 
@@ -284,7 +281,7 @@ class AssignmentPollDeleteView(DeleteView):
         super(AssignmentPollDeleteView, self).pre_post_redirect(request, *args, **kwargs)
 
     def set_assignment(self):
-        self.assignment = self.object.assignment
+        self.assignment = self.get_object().assignment
 
     def get_redirect_url(self, **kwargs):
         return reverse('assignment_detail', args=[self.assignment.id])
@@ -314,9 +311,9 @@ class AssignmentPDF(PDFView):
         except KeyError:
             assignment_id = None
         if assignment_id is None:  # print all assignments
-            title = config["assignment_pdf_title"]
+            title = escape(config["assignment_pdf_title"])
             story.append(Paragraph(title, stylesheet['Heading1']))
-            preamble = config["assignment_pdf_preamble"]
+            preamble = escape(config["assignment_pdf_preamble"])
             if preamble:
                 story.append(Paragraph(
                     "%s" % preamble.replace('\r\n', '<br/>'),
@@ -330,7 +327,7 @@ class AssignmentPDF(PDFView):
                 # List of assignments
                 for assignment in assignments:
                     story.append(Paragraph(
-                        assignment.name, stylesheet['Heading3']))
+                        escape(assignment.name), stylesheet['Heading3']))
                 # Assignment details (each assignment on single page)
                 for assignment in assignments:
                     story.append(PageBreak())
@@ -344,7 +341,7 @@ class AssignmentPDF(PDFView):
     def get_assignment(self, assignment, story):
         # title
         story.append(Paragraph(
-            _("Election: %s") % assignment.name, stylesheet['Heading1']))
+            _("Election: %s") % escape(assignment.name), stylesheet['Heading1']))
         story.append(Spacer(0, 0.5 * cm))
 
         # Filling table rows...
@@ -479,7 +476,7 @@ class AssignmentPDF(PDFView):
 
         # election description
         story.append(
-            Paragraph("%s" % assignment.description.replace('\r\n', '<br/>'),
+            Paragraph("%s" % escape(assignment.description).replace('\r\n', '<br/>'),
                       stylesheet['Paragraph']))
 
 
