@@ -2,8 +2,6 @@
 
 from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import reverse
-from django.db import models
-from django.utils.translation import ugettext_lazy, ugettext_noop
 
 from openslides.utils.utils import int_or_none
 
@@ -63,11 +61,16 @@ class SlideMixin(object):
 
     def delete(self, *args, **kwargs):
         """
-        Updates the projector, if the object is on the projector and is deleted.
+        Updates the projector if the object is on the projector and is deleted.
         """
         from openslides.projector.api import update_projector
+        # Checking active slide has to be done before calling super().delete()
+        # because super().delete() deletes the object and than we have no
+        # access to the former existing primary key any more. But updating
+        # projector has to be done after deleting the object of course.
+        update_required = self.is_active_slide()
         value = super(SlideMixin, self).delete(*args, **kwargs)
-        if self.is_active_slide():
+        if update_required:
             update_projector()
         return value
 
@@ -104,32 +107,3 @@ class SlideMixin(object):
         context.update({'slide': self,
                         slide_name: self})
         return context
-
-
-class ProjectorSlide(SlideMixin, models.Model):
-    """
-    Model for Slides, only for the projector. Also called custom slides.
-    """
-    # TODO: Rename it to CustomSlide
-    slide_callback_name = 'projector_slide'
-
-    title = models.CharField(max_length=256, verbose_name=ugettext_lazy("Title"))
-    text = models.TextField(null=True, blank=True, verbose_name=ugettext_lazy("Text"))
-    weight = models.IntegerField(default=0, verbose_name=ugettext_lazy("Weight"))
-
-    def get_absolute_url(self, link='update'):
-        if link == 'edit' or link == 'update':
-            return reverse('customslide_edit', args=[str(self.pk)])
-        if link == 'delete':
-            return reverse('customslide_delete', args=[str(self.pk)])
-        return super(ProjectorSlide, self).get_absolute_url(link)
-
-    def __unicode__(self):
-        return self.title
-
-    class Meta:
-        permissions = (
-            ('can_manage_projector', ugettext_noop("Can manage the projector")),
-            ('can_see_projector', ugettext_noop("Can see the projector")),
-            ('can_see_dashboard', ugettext_noop("Can see the dashboard")),
-        )
